﻿Fluke                                                       MET/CAL Procedure
=============================================================================
INSTRUMENT:            LeCroy WaveAce 222: (1 year) VER DOS /9500+1Hd
DATE:                  2017-04-07 14:20:47
AUTHOR:                LeCroy Corporation
REVISION:              $Revision: 2624 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       216
CONFIGURATION:         Datron 9500
CONFIGURATION:         Datron 9510 on channel 1
=============================================================================
#
#  Procedure Author:
#      FL, DAC, CAD
#
#  Source:
#      Lecroy WaveAce Performance Verification, Rev F
#
#  Compatibility:
#      MET/CAL 7.3 or later
#
#  Additional Equipment Required:
#      Type A male to type B male USB cable.
#
#  Due to OEM's policy of continuously updating products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, we cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  ASK-   R     N              P                   Z        F        V
  1.002  ASK+           K

# Dummy statements to force procedure header to include configuration
# required at run time.
  1.003  IF           0
  1.004  M9500                       CH1
  1.005  9500         200MH                        2Vpp           LS    S  L
  1.006  ENDIF

  1.007  IF           NOT(VERSIONCHECK("7.3"))
  1.008  DISP         This procedure requires Met/VERsion 7.3 or later.
  1.009  END
  1.010  ENDIF

  1.011  MATH         @Debug = 0

  1.012  HEAD         PRELIMINARY INSTRUCTIONS
  1.013  CALL         Sub Install LeCroy EasyScope
  1.014  CALL         Sub Display Copyright
  1.015  CALL         Sub High Voltage Safety Warning
  1.016  CALL         Sub Select Verification Method (No NTHROW)

  1.017  DISP         The calibration verification must be performed on
  1.017  DISP         an oscilloscope that has been warmed for at least
  1.017  DISP         15 minutes.  Turn ON and wait now if needed.

  1.018  DISP         Connect the PC to the UUT using Type A male to
  1.018  DISP         Type B male USB cable.

  1.019  MATH         @DataPath = "\"" & DFILE() & "\""

  1.020  HEAD         UUT IDENTIFICATION
  1.021  DOS          -x WaveAce.exe [V @DataPath] *RST

  1.022  MATH         @UUT_Manufacturer = "LECROY"
  1.023  MATH         @UUT_Model        = "WaveAce222"

  1.024  DO
  1.025  DOS          WaveAce.exe [V @DataPath] *IDN?
  1.026  MATH         HaveId = NOT(EMPTY(MEM2)) && FINDI(MEM2, "LeCroy", 0)

  1.027  IF           NOT(HaveId)
  1.028  OPBR         -z An error occurred while Identifying the
  1.028  OPBR         [V @UUT_Model].
  1.028  OPBR
  1.028  OPBR         Would you like to try again?

  1.029  IF           NOT(MEM1)
  1.030  HEAD         Procedure terminated!
  1.031  END
  1.032  ENDIF

  1.033  ENDIF

  1.034  UNTIL        HaveId

# Strip "*IDN " from the UUT's *IDN? response.  Example response:
# "*IDN LECROY,WaveAce<model number>,<serial number>,<firmware revision>"
  1.035  MATH         MEM2 = FLD(MEM2, 2, " ")
  1.036  CALL         Sub IEEE-488.2 Identification Query Parse Response
  1.037  CALL         Sub IEEE-488.2 Identification Query Check Response

  1.038  IF           @Abort
  1.039  END
  1.040  ENDIF

  1.041  IF           NOT(ZCMPI(@FirmwareRev, "1.01.01.13"))
  1.042  DISP         This DOS-based procedure only supports UUTs with
  1.042  DISP         firmware version 1.01.01.13.
  1.042  DISP
  1.042  DISP         All other firmware verions must use the VISA version of
  1.042  DISP         this same procedure.
  1.043  ENDIF

# Set: Number of channels; Bandwidth.
  1.044  MATH         @NumChan = 2; @Bandwidth = 200E+6

# NOTE: Throughout this procedure, JMPL/LABEL statements are used to minimize
# connection changes during execution. Test results, however, are reported in
# test number sequence, consistent with the source documentation.
#
# LeCroy WaveAce 2-Channel
#
#  Order  Results                            Run Time (Execution)
#  -----  ---------------------------------  ---------------------------------
#    1.   SELF-CALIBRATION                   SELF-CALIBRATION
#    2.   INPUT IMPEDANCE     (CH1)          INPUT IMPEDANCE     (CH1)
#    3.   INPUT IMPEDANCE     (CH2)          DC GAIN ACCURACY    (CH1)
#    4.   INPUT IMPEDANCE     (EXT TRIG)     BANDWIDTH           (CH1)
#    5.   DC GAIN ACCURACY    (CH1)          HORIZONTAL ACCURACY (CH1)
#    6.   DC GAIN ACCURACY    (CH2)          TRIGGER SENSITIVITY (CH1)
#    7.   BANDWIDTH           (CH1)          INPUT IMPEDANCE     (CH2)
#    8.   BANDWIDTH           (CH2)          DC GAIN ACCURACY    (CH2)
#    9.   HORIZONTAL ACCURACY (CH1)          BANDWIDTH           (CH2)
#   10.   TRIGGER SENSITIVITY (CH1)          TRIGGER SENSITIVITY (CH2)
#   11.   TRIGGER SENSITIVITY (CH2)          INPUT IMPEDANCE     (EXT TRIG)
#   12.   TRIGGER SENSITIVITY (EXT TRIG)     TRIGGER SENSITIVITY (EXT TRIG)

  1.045  CALL         Sub LeCroy WaveAce Self Calibration

  1.046  HEAD         INSTRUMENT CONNECTIONS
  1.047  DISP         Make the following connections:
  1.047  DISP
  1.047  DISP         [32]       9500          to     UUT
  1.047  DISP         [32]  CH 1 ACTIVE HEAD -------> CH1

  1.048  MATH         @Chan = 1
  1.049  CALL         Sub LeCroy WaveAce (1 yr) Ch Input Imped VER DOS /9500
  1.050  JMPL         DC_GAIN_CH1

  1.051  LABEL        INPUT_IMPEDANCE_CH2
  1.052  HEAD         INSTRUMENT CONNECTIONS
  1.053  DISP         Make the following connections:
  1.053  DISP
  1.053  DISP         [32]       9500          to     UUT
  1.053  DISP         [32]  CH 1 ACTIVE HEAD -------> CH2

  1.054  MATH         @Chan = 2
  1.055  CALL         Sub LeCroy WaveAce (1 yr) Ch Input Imped VER DOS /9500
  1.056  JMPL         DC_GAIN_CH2

  1.057  LABEL        INPUT_IMPEDANCE_EXT
  1.058  HEAD         INSTRUMENT CONNECTIONS
  1.059  DISP         Make the following connections:
  1.059  DISP
  1.059  DISP         [32]       9500          to     UUT
  1.059  DISP         [32]  CH 1 ACTIVE HEAD -------> EXT TRIG

  1.060  CALL         Sub LeCroy WaveAce (1 yr) Ext Input Imped VER DOS /9500
  1.061  JMPL         TRIGGER_SENSITIVITY_EXT

  1.062  LABEL        DC_GAIN_CH1
  1.063  MATH         @Chan = 1
  1.064  CALL         Sub LeCroy WaveAce (1 yr) DC Gain Acc VER DOS /9500
  1.065  JMPL         BANDWIDTH_CH1

  1.066  LABEL        DC_GAIN_CH2
  1.067  MATH         @Chan = 2
  1.068  CALL         Sub LeCroy WaveAce (1 yr) DC Gain Acc VER DOS /9500
  1.069  JMPL         BANDWIDTH_CH2

  1.070  LABEL        BANDWIDTH_CH1
  1.071  MATH         @Chan = 1
  1.072  CALL         Sub LeCroy WaveAce (1 yr) Bandwidth VER DOS /9500
  1.073  JMPL         HORIZONTAL_ACCURACY

  1.074  LABEL        BANDWIDTH_CH2
  1.075  MATH         @Chan = 2
  1.076  CALL         Sub LeCroy WaveAce (1 yr) Bandwidth VER DOS /9500
  1.077  JMPL         TRIGGER_SENSITIVITY_CH2

  1.078  LABEL        HORIZONTAL_ACCURACY
  1.079  MATH         @Chan = 1
  1.080  CALL         Sub LeCroy WaveAce (1 yr) Horizontal Acc VER DOS /9500

  1.081  CALL         Sub LeCroy WaveAce (1 yr) Int Trig Sens VER DOS /9500
  1.082  JMPL         INPUT_IMPEDANCE_CH2

  1.083  LABEL        TRIGGER_SENSITIVITY_CH2
  1.084  MATH         @Chan = 2
  1.085  CALL         Sub LeCroy WaveAce (1 yr) Int Trig Sens VER DOS /9500
  1.086  JMPL         INPUT_IMPEDANCE_EXT

  1.087  LABEL        TRIGGER_SENSITIVITY_EXT
  1.088  HEAD         INSTRUMENT CONNECTIONS
  1.089  DISP         Connect the 9500 CH1 ACTIVE HEAD to the Power Splitter
  1.089  DISP         input, using any necessary adapters.
  1.089  DISP
  1.089  DISP         Connect one output port of the Power Splitter
  1.089  DISP         to the UUT CH1 input.
  1.089  DISP
  1.089  DISP         Connect the other output port of the Power Splitter
  1.089  DISP         to the UUT EXT TRIG IN, via a 50 Ohm feedthrough
  1.089  DISP         termination.

  1.090  MATH         @Chan = 1
  1.091  CALL         Sub LeCroy WaveAce (1 yr) Ext Trg Sns VER DOS /9500+1Hd

  1.092  RSLT         =
  1.093  HEAD         {V E R I F I C A T I O N   C O M P L E T E}
  1.094  END
